==> com.liferay.dynamic.data.mapping.form.builder-3.0.4.jar: META-INF/resources/js/components/Form/FormRendererWithProvider.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.4/js/components/Form/FormRendererWithProvider.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-builder/js/util/visitors.es', './FormRenderer.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("dynamic-data-mapping-form-builder/js/util/visitors.es");

  var _FormRenderer2 = _interopRequireDefault(require("./FormRenderer.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FormRendererWithProvider =
  /*#__PURE__*/
  function (_FormRenderer) {
    _inherits(FormRendererWithProvider, _FormRenderer);

    function FormRendererWithProvider() {
      _classCallCheck(this, FormRendererWithProvider);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRendererWithProvider).apply(this, arguments));
    }

    _createClass(FormRendererWithProvider, [{
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(properties) {
        var pageVisitor = new _visitors.PagesVisitor(this.pages);
        var pages = pageVisitor.mapFields(function (field) {
          if (field.fieldName === properties.fieldInstance.fieldName) {
            return _objectSpread({}, field, {
              value: properties.value
            });
          }
        });
        this.pages = pages;
      }
    }, {
      key: "created",
      value: function created() {
        this.on('fieldEdited', this._handleFieldEdited);
      }
    }]);

    return FormRendererWithProvider;
  }(_FormRenderer2["default"]);

  var _default = FormRendererWithProvider;
  exports["default"] = _default;
  //# sourceMappingURL=FormRendererWithProvider.es.js.map
});
//# sourceMappingURL=FormRendererWithProvider.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-3.0.6.jar: META-INF/resources/js/components/Form/FormRendererWithProvider.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.6/js/components/Form/FormRendererWithProvider.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-builder/js/util/visitors.es', './FormRenderer.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("dynamic-data-mapping-form-builder/js/util/visitors.es");

  var _FormRenderer2 = _interopRequireDefault(require("./FormRenderer.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FormRendererWithProvider =
  /*#__PURE__*/
  function (_FormRenderer) {
    _inherits(FormRendererWithProvider, _FormRenderer);

    function FormRendererWithProvider() {
      _classCallCheck(this, FormRendererWithProvider);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRendererWithProvider).apply(this, arguments));
    }

    _createClass(FormRendererWithProvider, [{
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(properties) {
        var pageVisitor = new _visitors.PagesVisitor(this.pages);
        var pages = pageVisitor.mapFields(function (field) {
          if (field.fieldName === properties.fieldInstance.fieldName) {
            return _objectSpread({}, field, {
              value: properties.value
            });
          }
        });
        this.pages = pages;
      }
    }, {
      key: "created",
      value: function created() {
        this.on('fieldEdited', this._handleFieldEdited);
      }
    }]);

    return FormRendererWithProvider;
  }(_FormRenderer2["default"]);

  var _default = FormRendererWithProvider;
  exports["default"] = _default;
  //# sourceMappingURL=FormRendererWithProvider.es.js.map
});
//# sourceMappingURL=FormRendererWithProvider.es.js.map
